@@ -59,23 +59,27 @@ _wwwdir = os.path.join( package_home( globals() ), 'www' )
 manage_addGroupsFromLDAPMultiPluginForm = PageTemplateFile(
     os.path.join(_wwwdir, 'addGroupsFromLDAPMultiPlugin'),
     globals(),
-    __name__='manage_addGroupsFromLDAPMultiPlugin')
-
-def addGroupsFromLDAPMultiPlugin(self, id, title='', REQUEST=None):
-    """Factory method to instantiate a GroupsFromLDAPMultiPlugin."""
+    __name__='addGroupsFromLDAPMultiPlugin')
 
+def manage_addGroupsFromLDAPMultiPlugin(self, id, title, server, port,
+                                        managerdn, password, groupdn, scope,
+                                        objectclasses, escapevalues,
+                                        attributeid, attributetitle,
+                                        attributemembers, REQUEST=None):
+    """Factory method to instantiate a GroupsFromLDAPMultiPlugin.
+    """
     # Make sure we really are working in our container (the
-    # PluggableAuthService object)
+    # PluggableAuthService object.
     self = self.this()
 
     # Instantiate the folderish adapter object
     plugin = GroupsFromLDAPMultiPlugin(id, title=title)
     self._setObject(id, plugin)
-
+    plugin.manage_changeConfiguration(REQUEST, fromadd=True)
+    
     if REQUEST is not None:
         REQUEST.RESPONSE.redirect('%s/manage_main' % self.absolute_url())
-
-
+    
 class IGroupsFromLDAPMultiPlugin(Interface):
     """Marker Interface"""
 
@@ -552,7 +556,7 @@ class GroupsFromLDAPMultiPlugin(BasePlugin, Cacheable):
         return state, message
 
     security.declareProtected( ManageGroups, 'manage_changeConfiguration' )
-    def manage_changeConfiguration(self, REQUEST=None):
+    def manage_changeConfiguration(self, REQUEST=None, fromadd=False):
         """ manages submitted form """
         for key in REQUEST.form.keys():
             if key in self.config.keys():
@@ -566,10 +570,11 @@ class GroupsFromLDAPMultiPlugin(BasePlugin, Cacheable):
                     self.config[key] = self.config[key] == 'yes'
         self._p_changed = 1
         self.initializeLDAP()
+        if fromadd:
+            return
         return REQUEST.RESPONSE.redirect(self.absolute_url() +
                                          '/manage_LDAPBaseDNs')
 
-
     security.declareProtected( ManageGroups, 'manage_LDAPBaseDNs' )
     manage_LDAPBaseDNs = PageTemplateFile(
         os.path.join(_wwwdir, 'manage_base_dns'),
